# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: transport/internet/headers/dns/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Config",)

from dataclasses import dataclass

import betterproto2

from ......message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    domain: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)


default_message_pool.register_message(
    "xray.transport.internet.headers.dns", "Config", Config
)
