# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/vmess/account.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Account",)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Account(betterproto2.Message):
    id: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)
    """
    ID of the account, in the form of a UUID, e.g.,
    "66ad4540-b58c-4ad2-9926-ea63445a9b57".
    """

    security_settings: "__common__protocol__.SecurityConfig | None" = (
        betterproto2.field(3, betterproto2.TYPE_MESSAGE, optional=True)
    )
    """
    Security settings. Only applies to client side.
    """

    tests_enabled: "str" = betterproto2.field(4, betterproto2.TYPE_STRING)
    """
    Define tests enabled for this account
    """


default_message_pool.register_message("xray.proxy.vmess", "Account", Account)


from ...common import protocol as __common__protocol__
