# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: transport/internet/reality/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Config",)

from dataclasses import dataclass

import betterproto2

from .....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    show: "bool" = betterproto2.field(1, betterproto2.TYPE_BOOL)

    dest: "str" = betterproto2.field(2, betterproto2.TYPE_STRING)

    type: "str" = betterproto2.field(3, betterproto2.TYPE_STRING)

    xver: "int" = betterproto2.field(4, betterproto2.TYPE_UINT64)

    server_names: "list[str]" = betterproto2.field(
        5, betterproto2.TYPE_STRING, repeated=True
    )

    private_key: "bytes" = betterproto2.field(6, betterproto2.TYPE_BYTES)

    min_client_ver: "bytes" = betterproto2.field(7, betterproto2.TYPE_BYTES)

    max_client_ver: "bytes" = betterproto2.field(8, betterproto2.TYPE_BYTES)

    max_time_diff: "int" = betterproto2.field(9, betterproto2.TYPE_UINT64)

    short_ids: "list[bytes]" = betterproto2.field(
        10, betterproto2.TYPE_BYTES, repeated=True
    )

    fingerprint: "str" = betterproto2.field(21, betterproto2.TYPE_STRING)

    server_name: "str" = betterproto2.field(22, betterproto2.TYPE_STRING)

    public_key: "bytes" = betterproto2.field(23, betterproto2.TYPE_BYTES)

    short_id: "bytes" = betterproto2.field(24, betterproto2.TYPE_BYTES)

    spider_x: "str" = betterproto2.field(25, betterproto2.TYPE_STRING)

    spider_y: "list[int]" = betterproto2.field(
        26, betterproto2.TYPE_INT64, repeated=True
    )

    master_key_log: "str" = betterproto2.field(27, betterproto2.TYPE_STRING)


default_message_pool.register_message(
    "xray.transport.internet.reality", "Config", Config
)
