# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/dns/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Config",)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    server: "__common__net__.Endpoint | None" = betterproto2.field(
        1, betterproto2.TYPE_MESSAGE, optional=True
    )
    """
    Server is the DNS server address. If specified, this address overrides the
    original one.
    """

    user_level: "int" = betterproto2.field(2, betterproto2.TYPE_UINT32)

    non_IP_query: "str" = betterproto2.field(3, betterproto2.TYPE_STRING)

    block_types: "list[int]" = betterproto2.field(
        4, betterproto2.TYPE_INT32, repeated=True
    )


default_message_pool.register_message("xray.proxy.dns", "Config", Config)


from ...common import net as __common__net__
