# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/vless/account.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Account",)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Account(betterproto2.Message):
    id: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)
    """
    ID of the account, in the form of a UUID, e.g., "66ad4540-b58c-4ad2-9926-ea63445a9b57".
    """

    flow: "str" = betterproto2.field(2, betterproto2.TYPE_STRING)
    """
    Flow settings. May be "xtls-rprx-vision".
    """

    encryption: "str" = betterproto2.field(3, betterproto2.TYPE_STRING)
    """
    Encryption settings. Only applies to client side, and only accepts "none" for now.
    """


default_message_pool.register_message("xray.proxy.vless", "Account", Account)
