# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: transport/internet/httpupgrade/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Config",)

from dataclasses import dataclass

import betterproto2

from .....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    host: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)

    path: "str" = betterproto2.field(2, betterproto2.TYPE_STRING)

    header: "dict[str, str]" = betterproto2.field(
        3,
        betterproto2.TYPE_MAP,
        map_meta=betterproto2.map_meta(
            betterproto2.TYPE_STRING, betterproto2.TYPE_STRING
        ),
    )

    accept_proxy_protocol: "bool" = betterproto2.field(4, betterproto2.TYPE_BOOL)

    ed: "int" = betterproto2.field(5, betterproto2.TYPE_UINT32)


default_message_pool.register_message(
    "xray.transport.internet.httpupgrade", "Config", Config
)
