# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: app/dispatcher/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = (
    "Config",
    "SessionConfig",
)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    settings: "SessionConfig | None" = betterproto2.field(
        1, betterproto2.TYPE_MESSAGE, optional=True
    )


default_message_pool.register_message("xray.app.dispatcher", "Config", Config)


@dataclass(eq=False, repr=False)
class SessionConfig(betterproto2.Message):
    pass


default_message_pool.register_message(
    "xray.app.dispatcher", "SessionConfig", SessionConfig
)
