# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/vless/encoding/addons.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Addons",)

from dataclasses import dataclass

import betterproto2

from .....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Addons(betterproto2.Message):
    flow: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)

    seed: "bytes" = betterproto2.field(2, betterproto2.TYPE_BYTES)


default_message_pool.register_message("xray.proxy.vless.encoding", "Addons", Addons)
