# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: app/log/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = (
    "LogType",
    "Config",
)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


class LogType(betterproto2.Enum):
    None_ = 0

    Console = 1

    File = 2

    Event = 3


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    error_log_type: "LogType" = betterproto2.field(
        1, betterproto2.TYPE_ENUM, default_factory=lambda: LogType(0)
    )

    error_log_level: "__common__log__.Severity" = betterproto2.field(
        2, betterproto2.TYPE_ENUM, default_factory=lambda: __common__log__.Severity(0)
    )

    error_log_path: "str" = betterproto2.field(3, betterproto2.TYPE_STRING)

    access_log_type: "LogType" = betterproto2.field(
        4, betterproto2.TYPE_ENUM, default_factory=lambda: LogType(0)
    )

    access_log_path: "str" = betterproto2.field(5, betterproto2.TYPE_STRING)

    enable_dns_log: "bool" = betterproto2.field(6, betterproto2.TYPE_BOOL)

    mask_address: "str" = betterproto2.field(7, betterproto2.TYPE_STRING)


default_message_pool.register_message("xray.app.log", "Config", Config)


from ...common import log as __common__log__
