# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: app/stats/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = (
    "ChannelConfig",
    "Config",
)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class ChannelConfig(betterproto2.Message):
    blocking: "bool" = betterproto2.field(1, betterproto2.TYPE_BOOL)

    subscriber_limit: "int" = betterproto2.field(2, betterproto2.TYPE_INT32)

    buffer_size: "int" = betterproto2.field(3, betterproto2.TYPE_INT32)


default_message_pool.register_message("xray.app.stats", "ChannelConfig", ChannelConfig)


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    pass


default_message_pool.register_message("xray.app.stats", "Config", Config)
