# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/dokodemo/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Config",)

from dataclasses import dataclass

import betterproto2

from ....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    address: "__common__net__.IpOrDomain | None" = betterproto2.field(
        1, betterproto2.TYPE_MESSAGE, optional=True
    )

    port: "int" = betterproto2.field(2, betterproto2.TYPE_UINT32)

    networks: "list[__common__net__.Network]" = betterproto2.field(
        7, betterproto2.TYPE_ENUM, repeated=True
    )
    """
    List of networks that the Dokodemo accepts.
    """

    follow_redirect: "bool" = betterproto2.field(5, betterproto2.TYPE_BOOL)

    user_level: "int" = betterproto2.field(6, betterproto2.TYPE_UINT32)


default_message_pool.register_message("xray.proxy.dokodemo", "Config", Config)


from ...common import net as __common__net__
