# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: app/dns/fakedns/fakedns.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = (
    "FakeDnsPool",
    "FakeDnsPoolMulti",
)

from dataclasses import dataclass

import betterproto2

from .....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class FakeDnsPool(betterproto2.Message):
    ip_pool: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)
    """
    CIDR of IP pool used as fake DNS IP
    """

    lru_size: "int" = betterproto2.field(2, betterproto2.TYPE_INT64)
    """
    Size of Pool for remembering relationship between domain name and IP address
    """


default_message_pool.register_message(
    "xray.app.dns.fakedns", "FakeDnsPool", FakeDnsPool
)


@dataclass(eq=False, repr=False)
class FakeDnsPoolMulti(betterproto2.Message):
    pools: "list[FakeDnsPool]" = betterproto2.field(
        1, betterproto2.TYPE_MESSAGE, repeated=True
    )


default_message_pool.register_message(
    "xray.app.dns.fakedns", "FakeDnsPoolMulti", FakeDnsPoolMulti
)
