# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: common/log/log.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = ("Severity",)


import betterproto2

betterproto2.check_compiler_version("0.5.1")


class Severity(betterproto2.Enum):
    Unknown = 0

    Error = 1

    Warning = 2

    Info = 3

    Debug = 4
