# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: proxy/vmess/inbound/config.proto
# plugin: python-betterproto2
# This file has been @generated

__all__ = (
    "Config",
    "DefaultConfig",
    "DetourConfig",
)

from dataclasses import dataclass

import betterproto2

from .....message_pool import default_message_pool

betterproto2.check_compiler_version("0.5.1")


@dataclass(eq=False, repr=False)
class Config(betterproto2.Message):
    user: "list[___common__protocol__.User]" = betterproto2.field(
        1, betterproto2.TYPE_MESSAGE, repeated=True
    )

    default: "DefaultConfig | None" = betterproto2.field(
        2, betterproto2.TYPE_MESSAGE, optional=True
    )

    detour: "DetourConfig | None" = betterproto2.field(
        3, betterproto2.TYPE_MESSAGE, optional=True
    )
    """
    4 is for legacy setting
    """


default_message_pool.register_message("xray.proxy.vmess.inbound", "Config", Config)


@dataclass(eq=False, repr=False)
class DefaultConfig(betterproto2.Message):
    level: "int" = betterproto2.field(2, betterproto2.TYPE_UINT32)


default_message_pool.register_message(
    "xray.proxy.vmess.inbound", "DefaultConfig", DefaultConfig
)


@dataclass(eq=False, repr=False)
class DetourConfig(betterproto2.Message):
    to: "str" = betterproto2.field(1, betterproto2.TYPE_STRING)


default_message_pool.register_message(
    "xray.proxy.vmess.inbound", "DetourConfig", DetourConfig
)


from ....common import protocol as ___common__protocol__
